pub enum ConstraintCheckTime {
Deferred,
Immediate,
}Expand description
The SQL constraint check time forms represented by the AST.
Variants
Deferred
DEFERRED — check the constraints at transaction commit.
Immediate
IMMEDIATE — check the constraints at the end of each statement.