pub enum HandlerKeyComparison {
Eq,
GreaterOrEqual,
LessOrEqual,
Greater,
Less,
}Expand description
The key comparison of a HANDLER … READ <index> <op> (…) seek
(HandlerReadSelector::Key) — sql_yacc.yy handler_rkey_mode. A surface tag (no
meta). The set is exactly = >= <= > <; <>/!= are ER_PARSE_ERROR on mysql:8.
Variants
Eq
= — the first row whose index value equals the key.
GreaterOrEqual
>= — the first row whose index value is greater than or equal to the key.
LessOrEqual
<= — the last row whose index value is less than or equal to the key.
Greater
> — the first row whose index value is strictly greater than the key.
Less
< — the last row whose index value is strictly less than the key.